==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AClassFileType.h <==
// public final class soot.jimple.parser.node.AClassFileType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4d1040a21d5996d soot_jimple_parser_node_AClassFileType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f319b446d60a4f41 soot_jimple_parser_node_PFileType

// header file dependencies
// @dep_header soot_jimple_parser_node_PFileType

#include "soot/jimple/parser/node/PFileType.h"

#ifndef _JC_soot_jimple_parser_node_AClassFileType_H_
#define _JC_soot_jimple_parser_node_AClassFileType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TClass$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AClassFileType$sub_refs	_jc_soot_jimple_parser_node_AClassFileType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AClassFileType$sub_nonrefs	_jc_soot_jimple_parser_node_AClassFileType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassFileType$refs	_jc_soot_jimple_parser_node_AClassFileType$refs;
typedef struct _jc_soot_jimple_parser_node_AClassFileType$nonrefs	_jc_soot_jimple_parser_node_AClassFileType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassFileType$object	_jc_soot_jimple_parser_node_AClassFileType$object;

typedef const struct _jc_soot_jimple_parser_node_AClassFileType$vmethods	_jc_soot_jimple_parser_node_AClassFileType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AClassFileType$vtable	_jc_soot_jimple_parser_node_AClassFileType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AClassFileType$vtype	_jc_soot_jimple_parser_node_AClassFileType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AClassFileType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *);
extern void _jc_soot_jimple_parser_node_AClassFileType$method$_init$7d274a9b4478faff(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_TClass$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AClassFileType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AClassFileType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *);
extern struct _jc_soot_jimple_parser_node_TClass$object *_jc_soot_jimple_parser_node_AClassFileType$method$getTheclass$6f7d7d560a65938c(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *);
extern void _jc_soot_jimple_parser_node_AClassFileType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AClassFileType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AClassFileType$method$setTheclass$d01163355452e781(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_TClass$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AClassFileType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$getTheclass$6f7d7d560a65938c;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$setTheclass$d01163355452e781;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AClassFileType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *);
	struct _jc_soot_jimple_parser_node_TClass$object	*(*getTheclass$6f7d7d560a65938c)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setTheclass$d01163355452e781)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_TClass$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AClassFileType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PFileType$vmethods	soot_jimple_parser_node_PFileType;
	_jc_soot_jimple_parser_node_AClassFileType$vmethods	soot_jimple_parser_node_AClassFileType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AClassFileType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AClassFileType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassFileType$sub_refs {
	struct _jc_soot_jimple_parser_node_TClass$object	*__5ftheclass__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassFileType$refs {
    _jc_soot_jimple_parser_node_AClassFileType$sub_refs	soot_jimple_parser_node_AClassFileType;
    _jc_soot_jimple_parser_node_PFileType$sub_refs	soot_jimple_parser_node_PFileType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassFileType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassFileType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PFileType$sub_nonrefs	soot_jimple_parser_node_PFileType;
    _jc_soot_jimple_parser_node_AClassFileType$sub_nonrefs	soot_jimple_parser_node_AClassFileType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AClassFileType$object {
	_jc_soot_jimple_parser_node_AClassFileType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AClassFileType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AClassFileType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AClassFileType$vtype _jc_soot_jimple_parser_node_AClassFileType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AClassFileType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AClassFileType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AClassFileType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AClassFileType.h <==
// public final class soot.jimple.parser.node.AClassFileType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4d1040a21d5996d soot_jimple_parser_node_AClassFileType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f319b446d60a4f41 soot_jimple_parser_node_PFileType

// header file dependencies
// @dep_header soot_jimple_parser_node_PFileType

#include "soot/jimple/parser/node/PFileType.h"

#ifndef _JC_soot_jimple_parser_node_AClassFileType_H_
#define _JC_soot_jimple_parser_node_AClassFileType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TClass$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AClassFileType$sub_refs	_jc_soot_jimple_parser_node_AClassFileType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AClassFileType$sub_nonrefs	_jc_soot_jimple_parser_node_AClassFileType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassFileType$refs	_jc_soot_jimple_parser_node_AClassFileType$refs;
typedef struct _jc_soot_jimple_parser_node_AClassFileType$nonrefs	_jc_soot_jimple_parser_node_AClassFileType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassFileType$object	_jc_soot_jimple_parser_node_AClassFileType$object;

typedef const struct _jc_soot_jimple_parser_node_AClassFileType$vmethods	_jc_soot_jimple_parser_node_AClassFileType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AClassFileType$vtable	_jc_soot_jimple_parser_node_AClassFileType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AClassFileType$vtype	_jc_soot_jimple_parser_node_AClassFileType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AClassFileType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassFileType$method$_init$7d274a9b4478faff(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_TClass$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AClassFileType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AClassFileType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TClass$object *_jc_soot_jimple_parser_node_AClassFileType$method$getTheclass$6f7d7d560a65938c(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassFileType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassFileType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassFileType$method$setTheclass$d01163355452e781(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_TClass$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AClassFileType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$getTheclass$6f7d7d560a65938c;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$setTheclass$d01163355452e781;
extern _jc_method _jc_soot_jimple_parser_node_AClassFileType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AClassFileType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TClass$object	*(*getTheclass$6f7d7d560a65938c)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setTheclass$d01163355452e781)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *, struct _jc_soot_jimple_parser_node_TClass$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassFileType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AClassFileType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PFileType$vmethods	soot_jimple_parser_node_PFileType;
	_jc_soot_jimple_parser_node_AClassFileType$vmethods	soot_jimple_parser_node_AClassFileType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AClassFileType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AClassFileType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassFileType$sub_refs {
	struct _jc_soot_jimple_parser_node_TClass$object	*__5ftheclass__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassFileType$refs {
    _jc_soot_jimple_parser_node_AClassFileType$sub_refs	soot_jimple_parser_node_AClassFileType;
    _jc_soot_jimple_parser_node_PFileType$sub_refs	soot_jimple_parser_node_PFileType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassFileType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassFileType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PFileType$sub_nonrefs	soot_jimple_parser_node_PFileType;
    _jc_soot_jimple_parser_node_AClassFileType$sub_nonrefs	soot_jimple_parser_node_AClassFileType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AClassFileType$object {
	_jc_soot_jimple_parser_node_AClassFileType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AClassFileType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AClassFileType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AClassFileType$vtype _jc_soot_jimple_parser_node_AClassFileType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AClassFileType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AClassFileType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AClassFileType_H_ */
